<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>AptConfigMessage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="76"/>
        <source>Enter the number to configure: </source>
        <translation>請輸入序號進行配置：</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="81"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>確 定</translation>
    </message>
</context>
<context>
    <name>BackendProcessPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="16"/>
        <source>Loading packages...</source>
        <translation>正在載入安裝包…</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="17"/>
        <source>%1/%2 loaded</source>
        <translation>已載入%1/%2</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="20"/>
        <source>Initializing...</source>
        <translation>正在初始化…</translation>
    </message>
</context>
<context>
    <name>DdimErrorPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/ddimerrorpage.cpp" line="17"/>
        <source>OK</source>
        <translation>確 定</translation>
    </message>
</context>
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="107"/>
        <source>Package Installer</source>
        <translation>軟體包安裝器</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="115"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="598"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="699"/>
        <source>Installing other packages... Please open it later.</source>
        <translation>正在執行安裝流程，無法打開</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="602"/>
        <source>Parsing failed: An illegal file structure was found in the manifest file!</source>
        <translation>套裝軟體解析失敗，套裝軟體清單包含非法的文件結構！</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="604"/>
        <source>Parsing failed: An illegal version number was found in the manifest file!</source>
        <translation>套裝軟體解析失敗，套裝軟體清單包含非法版本號！</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="606"/>
        <source>No deb packages found. Please check the folder.</source>
        <translation>未檢測到安裝包，請檢查安裝目錄！</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="718"/>
        <source>The %1 package may be broken</source>
        <translation>請檢查%1包是否損壞</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="726"/>
        <source>You can only install local %1 packages</source>
        <translation>只能安裝本機的%1包</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="734"/>
        <source>No permission to access this folder</source>
        <translation>沒有權限訪問資料夾</translation>
    </message>
    <message>
        <source>The deb package may be broken</source>
        <translation type="vanished">請檢查deb包是否損壞</translation>
    </message>
    <message>
        <source>You can only install local deb packages</source>
        <translation type="vanished">只能安裝本機的deb包</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="750"/>
        <source>Already Added</source>
        <translation>已添加</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="759"/>
        <source>%1 does not exist, please reselect</source>
        <translation>%1文件不存在，請重新選擇文件</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="381"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="766"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="907"/>
        <source>Bulk Install</source>
        <translation>批次安裝</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="94"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="111"/>
        <source>Installation failed, please check your network connection</source>
        <translation>安裝失敗，請檢查網路連線</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="97"/>
        <source>Installation failed, please check for updates in Control Center</source>
        <translation>安裝失敗，請於控制中心檢查更新</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="99"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="103"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="115"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>安裝失敗，磁碟機空間不足</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="120"/>
        <source>No digital signature</source>
        <translation>無數位簽章</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="124"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="754"/>
        <source>Invalid digital signature</source>
        <translation>數位簽章無效</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="130"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="744"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1663"/>
        <source>The administrator has set policies to prevent installation of this package</source>
        <translation>管理員已限制，該軟體禁止安裝</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="136"/>
        <source>Installation Failed</source>
        <translation>安裝失敗</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="732"/>
        <source>current system</source>
        <translation>目前系統環境</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="735"/>
        <source>%2 has been installed in %1, please uninstall this package before installing it</source>
        <translation>已在%1中安裝%2，請先移除後再安裝此包</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="741"/>
        <source>Broken dependencies, try installing the app in compatibility mode</source>
        <translation>依賴關係不滿足，請嘗試使用相容模式安裝該應用</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="756"/>
        <source>Failed to install %1</source>
        <translation>%1安裝失敗</translation>
    </message>
    <message>
        <source>Failed to install %1: no valid digital singature</source>
        <translation type="vanished">無法安裝%1，安裝包無有效的數位簽章</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1116"/>
        <source>Unable to install - no digital signature</source>
        <translation>無法安裝，安裝包無數位簽章</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1117"/>
        <source>Please go to Control Center to enable developer mode and try again. Proceed?</source>
        <translation>請進入控制中心，開啟開發者模式後，再嘗試繼續安裝。是否前往？</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1120"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1121"/>
        <source>Proceed</source>
        <comment>button</comment>
        <translation>前 往</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1074"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1176"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1665"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>確 定</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1078"/>
        <source>Failed to install %1: no valid digital signature</source>
        <translation>無法安裝%1，安裝包無有效的數位簽章</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1214"/>
        <source>This package does not have a valid digital signature. Continue with the installation?</source>
        <translation>此安裝包沒有有效的數位簽章，是否繼續安裝？</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1216"/>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1217"/>
        <source>Continue</source>
        <comment>button</comment>
        <translation>繼續</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1072"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1173"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1662"/>
        <source>Unable to install</source>
        <translation>無法安裝</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1174"/>
        <source>This package does not have a valid digital signature</source>
        <translation>此安裝包沒有有效的數位簽章</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="759"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="764"/>
        <source>Broken dependencies: %1</source>
        <translation>缺少依賴軟體：%1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="128"/>
        <source>Authentication failed</source>
        <translation>配置授權失敗</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="711"/>
        <source>Unmatched package architecture</source>
        <translation>軟體套件結構不符合規範</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="48"/>
        <source>Drag deb packages here</source>
        <translation>拖曳軟體包到此</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="90"/>
        <source>Select File</source>
        <translation>選擇檔案</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="34"/>
        <source>Show details</source>
        <translation>顯示詳細訊息</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="34"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>隱 藏</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="169"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>安 裝</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="170"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>完 成</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="172"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>返 回</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="501"/>
        <source>Install %1 will remove: </source>
        <translation>安裝%1將會移除：</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="517"/>
        <source>Dependencies in the repository</source>
        <translation>倉庫中存在的依賴包</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="523"/>
        <source>Missing dependencies</source>
        <translation>倉庫中缺失的依賴包</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="575"/>
        <source>Installing dependencies: %1</source>
        <translation>正在安裝依賴：%1</translation>
    </message>
</context>
<context>
    <name>PackageSelectItem</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="82"/>
        <source>Same version installed</source>
        <translation>已安裝相同版本</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="85"/>
        <source>Earlier version installed: %1</source>
        <translation>已安裝舊版本：%1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="89"/>
        <source>Later version installed: %1</source>
        <translation>已安裝較新的版本：%1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="94"/>
        <source>Unmatched package architecture</source>
        <translation>軟體套件結構不符合規範</translation>
    </message>
</context>
<context>
    <name>PackageSelectView</name>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="22"/>
        <source>Select all</source>
        <translation>全選</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="23"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>安 裝</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="57"/>
        <source>Installing</source>
        <translation>正在安裝</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="61"/>
        <source>Installed</source>
        <translation>已安裝</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="69"/>
        <source>Failed</source>
        <translation>安裝失敗</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="65"/>
        <source>Waiting</source>
        <translation>等待安裝</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="232"/>
        <source>Same version installed</source>
        <translation>已安裝相同版本</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="234"/>
        <source>Later version installed: %1</source>
        <translation>已安裝較新的版本：%1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="236"/>
        <source>Earlier version installed: %1</source>
        <translation>已安裝舊版本：%1</translation>
    </message>
</context>
<context>
    <name>PackagesListView</name>
    <message>
        <location filename="../src/deb-installer/model/packagelistview.cpp" line="161"/>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="31"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="49"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="51"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>隱 藏</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="9"/>
        <source>Basic</source>
        <translation>基礎設定</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="10"/>
        <source>Check digital signatures if the developer mode is enabled</source>
        <translation>開發者模式下，檢測安裝包的簽名</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/settingdialog.cpp" line="82"/>
        <source>To install unsigned apps, go to Security Center &gt; Tools &gt; App Security, and select the app types that can be installed.</source>
        <translation>如需安裝未簽名應用，前往安全中心-安全工具-應用安全設定允許安裝的應用類型。</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/settingdialog.cpp" line="84"/>
        <source>Security Center &gt; Tools &gt; App Security</source>
        <translation>安全中心-安全工具-應用安全</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/uab/uab_package.cpp" line="45"/>
        <source>The system has not installed Linglong environment, please install it first</source>
        <translation>系統無玲瓏環境，請先安裝</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="42"/>
        <source>Unable to install</source>
        <translation>無法安裝</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="44"/>
        <source>This package does not have a valid digital signature and has been blocked from installing/running. Go to Security Center &gt; Tools &gt; App Security to change the settings.</source>
        <translation>安裝包沒有有效的數位簽章，已被禁止安裝/執行，請前往安全中心-安全工具-應用安全進行調整。</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="47"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="48"/>
        <source>Proceed</source>
        <comment>button</comment>
        <translation>前 往</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="264"/>
        <source>Will remove: </source>
        <translation>將會移除：</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="974"/>
        <source>Collapse</source>
        <translation>隱藏</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="482"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1151"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1338"/>
        <source>Reinstall</source>
        <translation>重 裝</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1155"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1342"/>
        <source>Later version installed: %1</source>
        <translation>已安裝較新的版本：%1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1156"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1343"/>
        <source>Downgrade</source>
        <translation>安裝舊版本</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1160"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1347"/>
        <source>Earlier version installed: %1</source>
        <translation>已安裝舊版本：%1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1243"/>
        <source>Installing dependencies: %1</source>
        <translation>正在安裝依賴：%1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1390"/>
        <source>Failed to install %1</source>
        <translation>%1安裝失敗</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="228"/>
        <source>Version: </source>
        <translation>版本：</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="177"/>
        <source>Select a compatibility mode:</source>
        <translation>選擇相容模式：</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="474"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>安 裝</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="478"/>
        <source>Remove</source>
        <comment>button</comment>
        <translation>移 除</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="486"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>確 定</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="490"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>返 回</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="494"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>完 成</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="731"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="770"/>
        <source>Trying to install %2 in %1 compatibility mode</source>
        <translation>正在嘗試使用%1相容模式安裝%2</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="808"/>
        <source>Uninstalling %2 from %1 compatibility mode</source>
        <translation>正在從%1相容模式移除%2</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="928"/>
        <source>%2 was successfully installed to %1 compatibility mode</source>
        <translation>%2已成功安裝到%1相容模式</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="932"/>
        <source>Installed successfully</source>
        <translation>安裝成功</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="941"/>
        <source>%2 has been successfully uninstalled from %1 compatibility mode</source>
        <translation>%2已從%1相容模式成功移除</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="945"/>
        <source>Uninstalled successfully</source>
        <translation>解除安裝成功</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="964"/>
        <source>Uninstall Failed</source>
        <translation>解除安裝失敗</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1004"/>
        <source>Install %1 will remove: </source>
        <translation>安裝%1將會移除：</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1024"/>
        <source>Dependencies in the repository</source>
        <translation>倉庫中存在的依賴包</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1030"/>
        <source>Missing dependencies</source>
        <translation>倉庫中缺失的依賴包</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1161"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1348"/>
        <source>Update</source>
        <comment>button</comment>
        <translation>更 新</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1395"/>
        <source>Invalid digital signature</source>
        <translation>數位簽章無效</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="216"/>
        <source>Name: </source>
        <translation>名稱：</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1150"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1337"/>
        <source>Same version installed</source>
        <translation>已安裝相同版本</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Install</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="49"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="717"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="756"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="925"/>
        <source>Show details</source>
        <translation>顯示詳細訊息</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="31"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="50"/>
        <source>Show dependencies</source>
        <translation>顯示依賴包關係</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Uninstall</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="794"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="938"/>
        <source>Show details</source>
        <translation>顯示卸載進程</translation>
    </message>
</context>
<context>
    <name>Uab::UabPackageListModel</name>
    <message>
        <location filename="../src/deb-installer/uab/uab_package_list_model.cpp" line="456"/>
        <source>Installation Failed</source>
        <translation>安裝失敗</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="16"/>
        <source>Show related packages</source>
        <translation>顯示相關軟體包</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="16"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>隱 藏</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="37"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="39"/>
        <source>Confirm</source>
        <translation>確 定</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="129"/>
        <source>Are you sure you want to uninstall %1?
All dependencies will also be removed</source>
        <translation>確定解除安裝 %1？
也會移除所有依賴</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="131"/>
        <source>Are you sure you want to uninstall %1?
The system or other applications may not work properly</source>
        <translation>您確定要移除%1嗎？
移除此軟體可能會導致系統或其他軟體無法正常使用</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="169"/>
        <source>Are you sure you want to uninstall %2 
from %1 compatibility mode?</source>
        <translation>您確定要從%1相容模式
移除%2嗎？</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="47"/>
        <location filename="../src/deb-installer/main.cpp" line="48"/>
        <source>Package Installer</source>
        <translation>軟體包安裝器</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="49"/>
        <source>Package Installer helps users install and remove local packages, and supports bulk installation.</source>
        <translation>軟體包安裝器用來幫助使用者安裝和移除本機軟體包。支援批次安裝。</translation>
    </message>
</context>
</TS>